<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>FontsDialog</name>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="28"/>
        <source>LabelsFont</source>
        <translation>Beschriftungen</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="31"/>
        <location filename="../../src/FontsDialog.cpp" line="51"/>
        <source>ResetDefaultValue</source>
        <translation>Rücksetzen</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="48"/>
        <source>FieldsFont</source>
        <translation>Felder</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="63"/>
        <source>LanguageFontOverrides</source>
        <translation>Schriftsätze für Sprachen</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="73"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="75"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="89"/>
        <source>Fonts Settings</source>
        <translation>Schriftsätze</translation>
    </message>
</context>
<context>
    <name>HelpBrowser</name>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="8"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="9"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="30"/>
        <source>Help: %1</source>
        <translation>Hilfe: %1</translation>
    </message>
</context>
<context>
    <name>KeyboardAcceleratorsDialog</name>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="23"/>
        <source>Action</source>
        <translation>Aktion</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="23"/>
        <source>Key</source>
        <translation>Taste</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="43"/>
        <source>Clear key</source>
        <translation>Taste löschen</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="44"/>
        <source>Set key</source>
        <translation>Taste festlegen</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="45"/>
        <source>Reset key</source>
        <translation>Taste zurücksetzen</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="63"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="87"/>
        <source>Keyboard Accelerator Definitions</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="122"/>
        <source>&lt;press key&gt;</source>
        <translation>&lt;Taste drücken&gt;</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="190"/>
        <source>Duplicate key binding</source>
        <translation>Doppelte Tastenbindung</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="191"/>
        <source>Key &apos;</source>
        <translation>Taste &apos;</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="191"/>
        <source>&apos;
is currently assigned to
&apos;</source>
        <translation>&apos;
ist gegenwärtig
&apos;</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="192"/>
        <source>&apos;.
Overwrite the current assignment?</source>
        <translation>&apos; zugewiesen. Zuweisung überschreiben?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/MainWindow.cpp" line="60"/>
        <location filename="../../src/MainWindow.cpp" line="176"/>
        <location filename="../../src/MainWindow.cpp" line="217"/>
        <source>StartQuiz</source>
        <translation>Quiz beginnen</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="62"/>
        <location filename="../../src/MainWindow.cpp" line="218"/>
        <source>ManageGlossaries</source>
        <translation>Glossare verwalten</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="64"/>
        <location filename="../../src/MainWindow.cpp" line="219"/>
        <source>Import...</source>
        <translation>Import Daten</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="66"/>
        <location filename="../../src/MainWindow.cpp" line="220"/>
        <source>Export...</source>
        <translation>Export Daten</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="70"/>
        <location filename="../../src/MainWindow.cpp" line="222"/>
        <source>Preferences...</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="72"/>
        <location filename="../../src/MainWindow.cpp" line="223"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="132"/>
        <location filename="../../src/MainWindow.cpp" line="236"/>
        <source>About...</source>
        <translation>Über toMOTko</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="176"/>
        <source>RestartQuiz</source>
        <translation>Quiz neu starten</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="68"/>
        <location filename="../../src/MainWindow.cpp" line="221"/>
        <source>ShowAllGlossariesAndTerms</source>
        <translation>Zeige alle Glossare und Begriffe</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="275"/>
        <source>AboutToMOTko...</source>
        <translation>Über toMOTko...</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="275"/>
        <source>AboutMessage</source>
        <translation>&lt;html&gt;&lt;h2&gt;toMOTko v0.11.2&lt;/h2&gt;&lt;p&gt;Eine kleine Applikation um neues Vokabular zu lernen.&lt;/p&gt;&lt;p&gt;Geschrieben von Frederic Bergeron&lt;br/&gt;(&lt;a href=&quot;mailto:fbergeron@users.sourceforge.net&quot;&gt;fbergeron@users.sourceforge.net&lt;/a&gt;)&lt;br/&gt;Copyright (c) 2006-2010&lt;/p&gt;&lt;p&gt;Diese Programm ist GPL v2.&lt;/p&gt;&lt;p&gt;Homepage: &lt;a href=&quot;http://tomotko.sourceforge.net&quot;&gt;http://tomotko.sourceforge.net&lt;/a&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="52"/>
        <location filename="../../src/MainWindow.cpp" line="213"/>
        <source>Reveal</source>
        <translation>Aufdecken</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="54"/>
        <location filename="../../src/MainWindow.cpp" line="214"/>
        <source>RightAnswer</source>
        <translation>Richtige Antwort</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="56"/>
        <location filename="../../src/MainWindow.cpp" line="215"/>
        <source>WrongAnswer</source>
        <translation>Falsche Antwort</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="58"/>
        <location filename="../../src/MainWindow.cpp" line="216"/>
        <source>EditQuizTerm</source>
        <translation>Wort bearbeiten</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="74"/>
        <location filename="../../src/MainWindow.cpp" line="224"/>
        <source>AddFolder</source>
        <translation>Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="76"/>
        <location filename="../../src/MainWindow.cpp" line="225"/>
        <source>AddGlossary</source>
        <translation>Glossar hinzufügen</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="78"/>
        <location filename="../../src/MainWindow.cpp" line="226"/>
        <source>RemoveItem</source>
        <translation>Eintrag entfernen</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="80"/>
        <location filename="../../src/MainWindow.cpp" line="227"/>
        <source>AddTerm</source>
        <translation>Wort hinzufügen</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="82"/>
        <location filename="../../src/MainWindow.cpp" line="228"/>
        <source>EditTerm</source>
        <translation>Wort bearbeiten</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="84"/>
        <location filename="../../src/MainWindow.cpp" line="229"/>
        <source>RemoveTerm</source>
        <translation>Wort(e) entfernen</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="86"/>
        <location filename="../../src/MainWindow.cpp" line="230"/>
        <source>CheckAllTerms</source>
        <translation>Alle Wörter wählen</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="88"/>
        <location filename="../../src/MainWindow.cpp" line="231"/>
        <source>InverseCheckedTerms</source>
        <translation>Auswahl invertieren</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="90"/>
        <location filename="../../src/MainWindow.cpp" line="232"/>
        <source>Maximize</source>
        <translation>Maximieren</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="298"/>
        <source>ConfirmResumeQuiz</source>
        <translation>Es wurde bereits ein Quiz für die gewählten Sprachen begonnen.&lt;br&gt;Möchten Sie es fortsetzen?</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="304"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="305"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="317"/>
        <source>NoTermsMarkedForStudy</source>
        <translation>Keine Wörter in den gewählten Sprachen zum Lernen gewählt. Das Quiz kann nicht beginnen. Benutzen Sie die Glossarverwaltung um Wörter zu wählen.</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="322"/>
        <source>TermsMissing</source>
        <translation>Die Worte werden nicht gefunden.  Das Quiz kann nicht gestartet werden.</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="92"/>
        <location filename="../../src/MainWindow.cpp" line="233"/>
        <source>Search...</source>
        <translation>Suche</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="130"/>
        <location filename="../../src/MainWindow.cpp" line="235"/>
        <source>Help...</source>
        <translation>Hilfe</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="73"/>
        <source>DigraphesEnabled</source>
        <translation>Digraphen ein</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="34"/>
        <source>Length</source>
        <translation>Quizlänge
(Wiederholungen)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="54"/>
        <source>QuizLengthShortest</source>
        <translation>Kurz (1)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="55"/>
        <source>QuizLengthMedium</source>
        <translation>Mittel (3)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="57"/>
        <source>QuizLengthLongest</source>
        <translation>Lang (5)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="87"/>
        <source>InterfaceLanguage</source>
        <translation>Sprache von Interface</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="143"/>
        <source>Revealing Sequences Settings</source>
        <translation>Aufdeckreihenfolge...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="189"/>
        <source>Preferences...</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="134"/>
        <source>Keyboard Accelerator Definitions</source>
        <translation>Tastenkürzel...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="76"/>
        <source>hideQuizButtons</source>
        <translation>Quizknöpfe verstecken</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="79"/>
        <source>ShowAltInTermList</source>
        <translation>Zeige alt./phon. Wert</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="137"/>
        <source>Study Language Definitions</source>
        <translation>Zu lernende Sprachen...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="140"/>
        <source>Fonts Settings</source>
        <translation>Schriftsätze...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="151"/>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="153"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>PropertiesPanel</name>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="59"/>
        <location filename="../../src/PropertiesPanel.cpp" line="92"/>
        <source>Words</source>
        <translation>Wörter</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="99"/>
        <source>Glossaries</source>
        <translation>Glossare</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="106"/>
        <source>Folders</source>
        <translation>Ordner</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="127"/>
        <location filename="../../src/PropertiesPanel.cpp" line="284"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="133"/>
        <location filename="../../src/PropertiesPanel.cpp" line="279"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="137"/>
        <location filename="../../src/PropertiesPanel.cpp" line="280"/>
        <source>Content</source>
        <translation>Inhalt</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Items</source>
        <translation>Einträge</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Selected</source>
        <translation>Quiz</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Checked</source>
        <translation>Gewählt</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="169"/>
        <location filename="../../src/PropertiesPanel.cpp" line="285"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="175"/>
        <location filename="../../src/PropertiesPanel.cpp" line="286"/>
        <source>CreationDate</source>
        <translation>Erstellungsdatum</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="181"/>
        <location filename="../../src/PropertiesPanel.cpp" line="287"/>
        <source>ModificationDate</source>
        <translation>Änderungsdatum</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>ar</source>
        <translation>Arabisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>bg</source>
        <translation>Bulgarisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>el</source>
        <translation>Griechisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>cs</source>
        <translation>Tschechische</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>da</source>
        <translation>Dänische</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>it</source>
        <translation>Italienisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>eo</source>
        <translation>Esperanto</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>fi</source>
        <translation>Finnische</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>he</source>
        <translation>Hebräische</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>hi</source>
        <translation>Hindi</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>hu</source>
        <translation>Ungarisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>ko</source>
        <translation>Koreanisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>nl</source>
        <translation>Holländisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>pt</source>
        <translation>Portugiesisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>la</source>
        <translation>Latein</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>no</source>
        <translation>Norwegisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>rm</source>
        <translation>Rätoromanisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>ru</source>
        <translation>Russisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>sw</source>
        <translation>Swahili</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>th</source>
        <translation>Thai</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>ro</source>
        <translation>Rumänische</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>sv</source>
        <translation>Schwedische</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>vi</source>
        <translation>Vietnamesisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>zh</source>
        <translation>Chinesisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>tl</source>
        <translation>Tagalog</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>en</source>
        <translation>Englisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>fr</source>
        <translation>Französisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>es</source>
        <translation>Spanisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>ja</source>
        <translation>Japanisch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>de</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="40"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="39"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="41"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="../../src/ResultListItem.cpp" line="20"/>
        <location filename="../../src/ResultListItem.cpp" line="33"/>
        <location filename="../../src/TermListItem.cpp" line="23"/>
        <location filename="../../src/TermListItem.cpp" line="36"/>
        <source>Undefined</source>
        <translation>Undefiniert</translation>
    </message>
    <message>
        <location filename="../../src/FolderParser.cpp" line="46"/>
        <location filename="../../src/MainWindow.cpp" line="270"/>
        <location filename="../../src/TermDialog.cpp" line="246"/>
        <location filename="../../src/VocabParser.cpp" line="85"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="270"/>
        <source>ErrorSavingData</source>
        <translation>Ein Fehler ist beim Speichern aufgetreten. Prüfen Sie die Berechtigungen und freien Speicherplatz.</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="288"/>
        <location filename="../../src/SequenceDialog.cpp" line="200"/>
        <location filename="../../src/SequenceDialog.cpp" line="206"/>
        <location filename="../../src/SequencesDialog.cpp" line="85"/>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="87"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="833"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="967"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="298"/>
        <location filename="../../src/MainWindow.cpp" line="317"/>
        <location filename="../../src/MainWindow.cpp" line="322"/>
        <location filename="../../src/QuizFrame.cpp" line="387"/>
        <location filename="../../src/QuizFrame.cpp" line="757"/>
        <location filename="../../src/QuizFrame.cpp" line="763"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="408"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="458"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="484"/>
        <source>OperationSuccessful</source>
        <translation>Aktion erfolgreich</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="416"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="419"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="460"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="486"/>
        <source>OperationFailed</source>
        <translation>Aktion fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../../src/FolderParser.cpp" line="47"/>
        <location filename="../../src/VocabParser.cpp" line="86"/>
        <source>ParseError</source>
        <translation>Parse Fehler in Zeile %1, Spalte %2. %3.</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="737"/>
        <source>MyGlossaries</source>
        <translation>Meine Glossare</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="144"/>
        <source>NewFolder</source>
        <translation>Neuer Ordner</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="173"/>
        <source>NewGlossary</source>
        <translation>Neues Glossar</translation>
    </message>
</context>
<context>
    <name>QuizFrame</name>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="104"/>
        <location filename="../../src/QuizFrame.cpp" line="139"/>
        <location filename="../../src/QuizFrame.cpp" line="149"/>
        <location filename="../../src/QuizFrame.cpp" line="187"/>
        <location filename="../../src/QuizFrame.cpp" line="202"/>
        <location filename="../../src/QuizFrame.cpp" line="636"/>
        <location filename="../../src/QuizFrame.cpp" line="639"/>
        <location filename="../../src/QuizFrame.cpp" line="640"/>
        <location filename="../../src/QuizFrame.cpp" line="643"/>
        <source>???</source>
        <translation>???</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="387"/>
        <source>WellDone</source>
        <translation>Gut gemacht! Sie haben alle %1 gewählten Wörter gelernt. Wählen Sie andere Wörter in der Glossarverwaltung um mehr Vokabular zu lernen.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="757"/>
        <location filename="../../src/QuizFrame.cpp" line="763"/>
        <source>DissociatedWord</source>
        <translation>Das Wort wurde von seinem ürsprünglichen Glossar deassoziiert. Es kann nicht vom Quiz aus bearbeitet werden.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="99"/>
        <location filename="../../src/QuizFrame.cpp" line="128"/>
        <location filename="../../src/QuizFrame.cpp" line="635"/>
        <location filename="../../src/QuizFrame.cpp" line="638"/>
        <source>Word/Expr.</source>
        <translation>Wort/Ausdr.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="126"/>
        <location filename="../../src/QuizFrame.cpp" line="637"/>
        <source>Alt./Phon.</source>
        <translation>Alt./Phon.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="169"/>
        <location filename="../../src/QuizFrame.cpp" line="642"/>
        <source>Examples/Comments</source>
        <translation>Beispiele/Kommentare</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="197"/>
        <location filename="../../src/QuizFrame.cpp" line="641"/>
        <source>Image</source>
        <translation>Bild</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="47"/>
        <location filename="../../src/SearchDialog.cpp" line="169"/>
        <source>Results</source>
        <translation>Ergebnisse</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="61"/>
        <location filename="../../src/SearchDialog.cpp" line="174"/>
        <source>Glossary</source>
        <translation>Glossar</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="61"/>
        <location filename="../../src/SearchDialog.cpp" line="174"/>
        <source>Location</source>
        <translation>Ort</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="72"/>
        <location filename="../../src/SearchDialog.cpp" line="176"/>
        <source>View Glossary</source>
        <translation>Glossar anzeigen</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="113"/>
        <location filename="../../src/SearchDialog.cpp" line="187"/>
        <source>Search...</source>
        <translation>Suche...</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="77"/>
        <location filename="../../src/SearchDialog.cpp" line="178"/>
        <source>Edit Term</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="82"/>
        <location filename="../../src/SearchDialog.cpp" line="180"/>
        <source>Remove Term(s)</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="88"/>
        <location filename="../../src/SearchDialog.cpp" line="182"/>
        <source>Close</source>
        <translation>Schlieβen</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="170"/>
        <location filename="../../src/SearchDialog.cpp" line="208"/>
        <source>%1 term(s) found</source>
        <translation>%1 Wort(e) gefunden</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="288"/>
        <source>ConfirmRemoveSelectedTerms</source>
        <translation>Möchten Sie wiklich die gewählten Worte entfernen?</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="294"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="295"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="336"/>
        <source>MultipleTranslationsDetectedForRemoveTermsCaption</source>
        <translation>Wörter entfernen</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="336"/>
        <source>MultipleTranslationsDetectedForRemoveTerms</source>
        <translation>Manche der gewählten Worte enthalten mehrere Übersetzungen in mehreren Sprachen. Bitte wählen Sie die zu löschenden Übersetzungen.</translation>
    </message>
</context>
<context>
    <name>SequenceDialog</name>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="22"/>
        <source>Quiz</source>
        <translation>Quizfenster</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="52"/>
        <source>FirstLanguage</source>
        <translation>Erste Sprache</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="56"/>
        <location filename="../../src/SequenceDialog.cpp" line="88"/>
        <source>Word/Expr.</source>
        <translation>Wort/Ausdr.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="72"/>
        <source>TestLanguage</source>
        <translation>Testsprache</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="86"/>
        <source>Alt./Phon.</source>
        <translation>Alt./Phon.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="102"/>
        <source>Image</source>
        <translation>Bild</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="115"/>
        <source>CommentLabelPanel</source>
        <translation>Beispiele/Kommentare</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="128"/>
        <source>Sequence</source>
        <translation>Reihenfolge</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="191"/>
        <source>AddRevealingSequence</source>
        <translation>Aufdeckreihenfolge hinzufügen...</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="200"/>
        <source>SequenceIsEmpty</source>
        <translation>Die gerade bearbeitete Aufdeckreihenfolge ist leer. Wenn Sie sie löschen möchten, wählen Sie &apos;Abbrechen&apos; um das Fenster zu schließen.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="206"/>
        <source>SequenceNotTerminated</source>
        <translation>Die gerade bearbeitete Aufdeckreihenfolge endet nicht mit einem aufdeckbaren Eintrag. Entfernen Sie den letzen Operator oder fügen Sie einen aufdeckbaren Eintrag an.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="166"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="168"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>SequencesDialog</name>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="23"/>
        <source>Existing Sequences</source>
        <translation>Reihenfolge</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="47"/>
        <source>QuizWindow</source>
        <translation>Quizfenster</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="62"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="64"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="78"/>
        <source>RevealingOrders</source>
        <translation>Aufdeckreihenfolge</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="85"/>
        <source>RevealingOrderMandatory</source>
        <translation>Sie müssen zumindest eine Aufdeckreihenfolge wählen. Wenn keine verfügbar ist, erstellen Sie bitte eine.</translation>
    </message>
</context>
<context>
    <name>StudyLanguagesDialog</name>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="26"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="28"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="45"/>
        <source>Study Language Definitions</source>
        <translation>Zu lernende Sprachen</translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="87"/>
        <source>StudyLanguagesMandatory</source>
        <translation>Sie müssen zumindest zwei Studiensprachen wählen
(eine Quell- und eine Zielsprache).</translation>
    </message>
</context>
<context>
    <name>TermDialog</name>
    <message>
        <location filename="../../src/TermDialog.cpp" line="62"/>
        <location filename="../../src/TermDialog.cpp" line="84"/>
        <source>Word/Expr.</source>
        <translation>Wort/Ausdr.</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="82"/>
        <source>Alt./Phon.</source>
        <translation>Alt./Phon.</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="109"/>
        <source>Examples/Comments</source>
        <translation>Beispiele/Kommentare</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="167"/>
        <source>EditTerm</source>
        <translation>Wort bearbeiten</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="137"/>
        <source>Image</source>
        <translation>Bild</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="128"/>
        <source>setImage</source>
        <translation>Setzen</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="132"/>
        <source>clearImage</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="214"/>
        <source>SetImage...</source>
        <translation>Bild setzen...</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="148"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="150"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="214"/>
        <source>Images (*.png *.gif)</source>
        <translation>Bilder (*.png *.gif)</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="246"/>
        <source>CannotReadImage</source>
        <translation>Das Bild konnte nicht gelesen werden.</translation>
    </message>
</context>
<context>
    <name>TranslationSelectionDialog</name>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="15"/>
        <source>Languages</source>
        <translation>Sprachen</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="37"/>
        <source>CheckAllLanguages</source>
        <translation>Alle Sprachen auswählen</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="45"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="47"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>Util</name>
    <message>
        <location filename="../../src/Util.cpp" line="22"/>
        <source>VerySmall</source>
        <translation>Sehr klein</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="23"/>
        <source>Small</source>
        <translation>Klein</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="24"/>
        <source>Medium</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="25"/>
        <source>Large</source>
        <translation>Groß</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="26"/>
        <source>VeryLarge</source>
        <translation>Sehr groß</translation>
    </message>
</context>
<context>
    <name>VocabularyManagerFrame</name>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="1015"/>
        <source>MultipleTranslationsDetectedForRemoveTermsCaption</source>
        <translation>Wörter entfernen</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="1015"/>
        <source>MultipleTranslationsDetectedForRemoveTerms</source>
        <translation>Manche der gewählten Worte enthalten mehrere Übersetzungen in mehreren Sprachen. Bitte wählen Sie die zu löschenden Übersetzungen.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="361"/>
        <source>MultipleTranslationsDetectedForImport</source>
        <translation>Die Daten die Sie importieren möchten enthalten mehrere Übersetzungen. Bitte wählen Sie die zu importierenden Übersetzungen.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="442"/>
        <source>MultipleTranslationsDetectedForExport</source>
        <translation>Die Daten die Sie exportieren möchten enthalten mehrere Übersetzungen. Bitte wählen Sie die zu exportierenden Übersetzungen.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="839"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="973"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="840"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="974"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="46"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="596"/>
        <source>Glossaries</source>
        <translation>Glossare</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="458"/>
        <source>GlossaryExportSuccessful</source>
        <translation>Das Glossar wurde erfolgreich exportiert.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="416"/>
        <source>ItemImportFailed</source>
        <translation>Ein Fehler ist aufgetreten. Es wurden keine Daten importiert.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="419"/>
        <source>ItemImportFailedZipFileExpected</source>
        <translation>Falsches Dateiformat - keine Zip Datei. Es wurden keine Daten importiert.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="460"/>
        <source>GlossaryExportFailed</source>
        <translation>Ein Fehler ist aufgetreten. Das Glossar wurde nicht exportiert.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="833"/>
        <source>ConfirmRemoveItem</source>
        <translation>Möchten Sie diesen Eintrag wirklich entfernen?</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="967"/>
        <source>ConfirmRemoveSelectedTerms</source>
        <translation>Möchten Sie die gewählten Worte wirklich entfernen?</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="186"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="604"/>
        <source>Properties</source>
        <translation>Eigenschaften</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="187"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="605"/>
        <source>Words</source>
        <translation>Wörter</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="468"/>
        <source>MultipleTranslationsDetectedForFolderExport</source>
        <translation>Der Ordner enthält Wörter mit Übersetzungen in mehreren Sprachen. Bitte wählen Sie die zu exportierenden Übersetzungen.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="484"/>
        <source>FolderExportSuccessful</source>
        <translation>Der Ordner wurde erfolgreich exportiert.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="486"/>
        <source>FolderExportFailed</source>
        <translation>Ein Fehler ist aufgetreten. Der Ordner wurde nicht exportiert.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="353"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="361"/>
        <source>Import...</source>
        <translation>Importieren...</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="405"/>
        <source>ImportSuccessful</source>
        <translation>Die Daten wurden erfolgreich importiert.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="407"/>
        <source>InvisibleImport</source>
        <translation>

Die neuen Daten sind zur Zeit nicht sichtbar. Sie müssen die entsprechenden Sprachen wählen.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="442"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="453"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="468"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="479"/>
        <source>Export...</source>
        <translation>Exportieren...</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="353"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="454"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="480"/>
        <source>Glossaries (*.zip)</source>
        <translation>Glossare (*.zip)</translation>
    </message>
</context>
</TS>
